@@ -54,6 +54,11 @@ if [ "$DEB_TARGET_GNU_SYSTEM" = "gnu" ] ; then
 	if [ ! -e $TARGET/libexec/runsystem -a -e $TARGET/libexec/runsystem.gnu ] ; then
 		cp $TARGET/libexec/runsystem.gnu $TARGET/libexec/runsystem
 	fi
+	#####################################
+	# create passive translators if the 
+	# host system is able to
+	#####################################
+	gnu_setup_passive_translators
 fi
 
 cp /usr/share/crosshurd/native-install $TARGET
